@@ -2,7 +2,7 @@
 
 __author__ = """PragmaLingu"""
 __email__ = 'info@pragmalingu.de'
-__version__ = '0.0.1'
+__version__ = '0.0.3'
 
 from collections import OrderedDict, defaultdict
 import pandas as pd
@@ -11,6 +11,13 @@ from elasticsearch import Elasticsearch
 import json
 
 
+from collections import OrderedDict, defaultdict
+import pandas as pd
+import seaborn as sns
+from elasticsearch import Elasticsearch
+import json
+import re
+
 class EvaluationObject:
     def __init__(self, host, query_rel_dict, index, name):
         self.queries_rels = query_rel_dict
@@ -397,6 +404,51 @@ class EvaluationObject:
         else:
             self.fscore = fscore
 
+    def explain_query(self, doc_id, query_id, fields=['text', 'title']):
+        """
+        Returns an Elasticsearch explanation for given query
+        :param query_id: int, query that should be explained
+        :param doc_id: int, id of document that should be explained
+        :param fields: list of str, fields that should be searched on
+        :return: json
+        """
+        query_body = {
+                "query": {
+                    "multi_match": {
+                        "fields": fields,
+                        "query":  self.queries_rels[query_id]['question']
+                    }
+                }
+            }
+        explanation = self.elasticsearch.explain(self.index, doc_id, query_body)['explanation']
+        explain = defaultdict(lambda: defaultdict(lambda: []))
+        explain["score"] = explanation['value']
+        for el in explanation['details']:
+            field = ''.join(f for f in fields if re.search(f, el['details'][0]['description']))
+            explain[field]["total_value"] = el['details'][0]['value']
+            explain[field]["details"] = []
+            for detail in el['details']:
+                doc_freq = 0
+                term_freq = 0.0
+                for val in detail['details'][0]["details"]:
+                    try:
+                        if re.match('n, number of documents', val["details"][0]["description"]):
+                            doc_freq = val["details"][0]["value"]
+                    except IndexError:
+                        continue
+                    try:
+                        if re.match(r'[Ff]req', val["details"][0]["description"]):
+                            term_freq = val["details"][0]["value"]
+                    except IndexError:
+                        continue
+                explain[field]["details"].append(
+                    {"function": {
+                "value": detail['value'],
+                "description": detail['description'],
+                "n, number of documents containing term": doc_freq,
+                "freq, occurrences of term within document": term_freq}})
+        return json.dumps(explain, indent=4)
+
 
 class ComparisonTool:
     def __init__(self, host, index_1, index_2, eval_obj_1=None, eval_obj_2=None, name_1='approach_1',
@@ -462,7 +514,9 @@ class ComparisonTool:
                 if not any(res_2['doc']['id'] in el['doc'].values() for el in
                            getattr(self.eval_obj_1, distribution)[query][distribution]):
                     results[query][distribution + ' ' + self.eval_obj_2.name].append(res_2)
-        return results
+            results[query]['count'] = len(results[query][distribution + ' ' + self.eval_obj_1.name])+len(results[query][distribution + ' ' + self.eval_obj_2.name])
+        ordered_results = OrderedDict(sorted(results.items(), key=lambda i: i[1]['count']))
+        return ordered_results
 
     def print_vis(self, params=None):
         """
